AudioIOLayout

Struct AudioIOLayout 

pub struct AudioIOLayout {
    pub main_input_channels: Option<NonZero<u32>>,
    pub main_output_channels: Option<NonZero<u32>>,
    pub aux_input_ports: &'static [NonZero<u32>],
    pub aux_output_ports: &'static [NonZero<u32>],
    pub names: PortNames,
}
A description of a plugin’s audio IO configuration. The Plugin defines a list of supported audio IO configs, with the first one acting as the default layout. Depending on the plugin API, the host may pick a different configuration from the list and use that instead. The final chosen configuration is passed as an argument to the Plugin::initialize() function so the plugin can allocate its data structures based on the number of audio channels it needs to process.

Fields

main_input_channels: Option<NonZero<u32>>

The number of main input channels for the plugin, if it has a main input port. This can be set to None if the plugin does not have one.

main_output_channels: Option<NonZero<u32>>

The number of main output channels for the plugin, if it has a main output port. This can be set to None if the plugin does not have one.

aux_input_ports: &'static [NonZero<u32>]

The plugin’s additional sidechain inputs, if it has any. Use the new_nonzero_u32() function to construct these values until const Option::unwrap() gets stabilized (https://github.com/rust-lang/rust/issues/67441).

aux_output_ports: &'static [NonZero<u32>]

The plugin’s additional outputs, if it has any. Use the new_nonzero_u32() function to construct these values until const Option::unwrap() gets stabilized (https://github.com/rust-lang/rust/issues/67441).

names: PortNames

Optional names for the audio ports. Defining these can be useful for plugins with multiple output and input ports.

Implementations

Source

impl AudioIOLayout

pub const fn const_default() -> AudioIOLayout

AudioIOLayout::default(), but as a const function. Used when initializing Plugin::AUDIO_IO_LAYOUTS. (https://github.com/rust-lang/rust/issues/67792)

pub fn name(&self) -> String

A descriptive name for the layout. This is taken from PortNames::layout if set. Otherwise it is generated based on the layout.

pub fn main_input_name(&self) -> String

The name for the main input port. Either generated or taken from the names field.

pub fn main_output_name(&self) -> String

The name for the main output port. Either generated or taken from the names field.

pub fn aux_input_name(&self, idx: usize) -> Option<String>

The name for the auxiliary input port with the given index. Either generated or taken from the names field.

pub fn aux_output_name(&self, idx: usize) -> Option<String>

The name for the auxiliary output port with the given index. Either generated or taken from the names field.