pub struct NativeSize<P> {
pub width: P,
pub height: P,
}Expand description
A size represented in the platform’s native pixels.
This size is represented in physical pixels on Windows and Linux, and in logical pixels on macOS.
(This is a re-implementation of
baseview::dpi::NativeSize
to avoid directly depending on baseview until it is stabilized.)
Fields
width: Pheight: PImplementations
Sourceimpl<P> NativeSize<P>
impl<P> NativeSize<P>
pub const fn new(width: P, height: P) -> NativeSize<P>
Sourceimpl<P> NativeSize<P>where
P: Pixel,
impl<P> NativeSize<P>where
P: Pixel,
pub fn from_size(size: Size, scale_factor: f64) -> NativeSize<P>
pub fn from_logical_or_physical( logical_size: LogicalSize<f64>, physical_size: PhysicalSize<u32>, ) -> NativeSize<P>
pub fn cast<X>(&self) -> NativeSize<X>where
X: Pixel,
pub fn to_physical(self, scale_factor: f64) -> PhysicalSize<P>
pub fn to_logical(self, scale_factor: f64) -> LogicalSize<P>