macro_rules! nice_export_vst3 {
($($plugin_ty:ty),+) => { ... };
}Expand description
Export one or more VST3 plugins from this library using the provided plugin types. The first plugin’s vendor information is used for the factory’s information.
macro_rules! nice_export_vst3 {
($($plugin_ty:ty),+) => { ... };
}Export one or more VST3 plugins from this library using the provided plugin types. The first plugin’s vendor information is used for the factory’s information.