ParamFlags

Struct ParamFlags 

pub struct ParamFlags(/* private fields */);
Flags for controlling a parameter’s behavior.

Implementations

Source

impl ParamFlags

pub const BYPASS: ParamFlags

When applied to a BoolParam, this will cause the parameter to be linked to the host’s bypass control. Only a single parameter can be marked as a bypass parameter. If you don’t have a bypass parameter, then nice-plug will add one for you. You will need to implement this yourself if your plugin introduces latency.

pub const NON_AUTOMATABLE: ParamFlags

The parameter cannot be changed from an automation lane. The parameter can however still be manually changed by the user from either the plugin’s own GUI or from the host’s generic UI.

pub const HIDDEN: ParamFlags

Hides the parameter in the host’s generic UI for this plugin. This also implies NON_AUTOMATABLE. Setting this does not prevent you from changing the parameter in the plugin’s editor GUI.

pub const HIDE_IN_GENERIC_UI: ParamFlags

Don’t show this parameter when generating a generic UI for the plugin using one of nice-plug’s generic UI widgets.

Source

impl ParamFlags

pub const fn empty() -> ParamFlags

Get a flags value with all bits unset.

pub const fn all() -> ParamFlags

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<ParamFlags>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> ParamFlags

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> ParamFlags

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<ParamFlags>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: ParamFlags) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: ParamFlags) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: ParamFlags)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: ParamFlags)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: ParamFlags)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: ParamFlags, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: ParamFlags) -> ParamFlags

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: ParamFlags) -> ParamFlags

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: ParamFlags) -> ParamFlags

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: ParamFlags) -> ParamFlags

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> ParamFlags

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl ParamFlags

pub const fn iter(&self) -> Iter<ParamFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ParamFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.