TrackInfo

Struct TrackInfo 

pub struct TrackInfo { /* private fields */ }
Information about the track the plugin is currently placed on. Not all hosts provide this information, and not all fields may be available at once.

Implementations

Source

impl TrackInfo

pub fn new(name: impl Into<String>, color: Option<TrackColor>) -> TrackInfo

pub fn name(&self) -> &str

pub fn color(&self) -> Option<TrackColor>