macro_rules! nice_export_clap {
($($plugin_ty:ty),+) => { ... };
}Expand description
Export one or more CLAP plugins from this library using the provided plugin types.
macro_rules! nice_export_clap {
($($plugin_ty:ty),+) => { ... };
}Export one or more CLAP plugins from this library using the provided plugin types.