TaskExecutor

Type Alias TaskExecutor 

pub type TaskExecutor<P> = Box<dyn Fn(<P as Plugin>::BackgroundTask) + Send>;
A function that can execute a plugin’s BackgroundTasks. A plugin can dispatch these tasks from the initialize() function, the process() function, or the GUI, so they can be deferred for later to avoid blocking realtime contexts.

Aliased Type

pub struct TaskExecutor<P>(/* private fields */);