Module event
nice_
plug
0.2.0
Module event
Module Items
Structs
In nice_
plug::
tracing
nice_plug
::
tracing
Module
event
Events represent single points in time during the execution of a program.
Structs

Event
Event
s represent single points in time where something occurred during the execution of a program.