Modules
- features
- Features a plugin supports. This is essentially the same thing as tags, keyword, or categories. Hosts may use these to organize plugins.
Structs
- Plugin
Descriptor - Re-export for the macro A static descriptor for a plugin. This is used in both the descriptor and on the plugin object itself.
- Poly
Modulation Config - Configuration for the plugin’s polyphonic modulation options, if it supports .
- Wrapper
- clap_
host - clap_
plugin - clap_
plugin_ descriptor - clap_
plugin_ entry - clap_
plugin_ factory
Constants
Traits
- Clap
Plugin - Provides auxiliary metadata needed for a CLAP plugin.