pub struct PluginDescriptor { /* private fields */ }Expand description
Re-export for the macro A static descriptor for a plugin. This is used in both the descriptor and on the plugin object itself.
This cannot be cloned as clap_features_ptrs contains pointers to clap_features.
Implementations
Sourceimpl PluginDescriptor
impl PluginDescriptor
Sourcepub fn for_plugin<P: ClapPlugin>() -> Self
pub fn for_plugin<P: ClapPlugin>() -> Self
Construct the plugin descriptor for a specific CLAP plugin.
pub fn clap_plugin_descriptor(&self) -> &clap_plugin_descriptor
pub fn clap_id(&self) -> &CStr