PolyModulationConfig

Struct PolyModulationConfig 

pub struct PolyModulationConfig {
    pub max_voice_capacity: u32,
    pub supports_overlapping_voices: bool,
}
Configuration for the plugin’s polyphonic modulation options, if it supports .

Fields

max_voice_capacity: u32

The maximum number of voices this plugin will ever use. Call the context’s set_current_voice_capacity() method during initialization or audio processing to set the polyphony limit.

supports_overlapping_voices: bool

If set to true, then the host may send note events for the same channel and key, but using different voice IDs. Bitwig Studio, for instance, can use this to do voice stacking. After enabling this, you should always prioritize using voice IDs to map note events to voices.