A standalone plugin target that directly connects to the system’s audio and MIDI ports instead of relying on a plugin host. This is mostly useful for quickly testing GUI changes.
Functions
- nice_
export_ standalone - Open an nice-plug plugin as a standalone application. If the plugin has an editor, this will open
the editor and block until the editor is closed. Otherwise this will block until SIGINT is
received. This is mainly useful for quickly testing plugin GUIs. In order to use this, you will
first need to make your plugin’s main struct
puband expose alibartifact in addition to your plugin’scdylib: - nice_
export_ standalone_ with_ args - The same as
nice_export_standalone(), but with the arguments taken from an iterator instead of usingstd::env::args().