PluginInfo

Struct PluginInfo 

pub struct PluginInfo {
    pub cid: &'static [u8; 16],
    pub name: &'static str,
    pub subcategories: String,
    pub vendor: &'static str,
    pub version: &'static str,
    pub url: &'static str,
    pub email: &'static str,
}
Re-export for the wrapper. The information queried about a plugin through the IPluginFactory* methods. Stored in a separate struct so it can be type erased and stored in an array.

Fields

cid: &'static [u8; 16]name: &'static strsubcategories: Stringvendor: &'static strversion: &'static strurl: &'static stremail: &'static str

Implementations

Source

impl PluginInfo

pub fn for_plugin<P: Vst3Plugin>() -> PluginInfo

pub fn create_factory_info(&self) -> PFactoryInfo

Fill a PFactoryInfo struct with the information from this library. Used in IPluginFactory.

pub fn create_class_info(&self) -> PClassInfo

Fill a PClassInfo struct with the information from this library. Used in IPluginFactory.

pub fn create_class_info_2(&self) -> PClassInfo2

Fill a PClassInfo2 struct with the information from this library. Used in IPluginFactory2.

pub fn create_class_info_unicode(&self) -> PClassInfoW

Fill a PClassInfoW struct with the information from this library. Used in IPluginFactory3.