Module subcategories

Module subcategories 

Subcategories for VST3 plugins. This is essentially the same thing as tags, keyword, or categories. Hosts may use these to organize plugins.

Enums

Vst3SubCategory
A subcategory for a VST3 plugin. See https://github.com/steinbergmedia/vst3_pluginterfaces/blob/bc5ff0f87aaa3cd28c114810f4f03c384421ad2c/vst/ivstaudioprocessor.h#L49-L90 for a list of all predefined subcategories. Multiple subcategories are concatenated to a string separated by pipe characters, and the total length of this string may not exceed 127 characters.