pub struct TrackInfo { /* private fields */ }Expand description
Information about the track the plugin is currently placed on. Not all hosts provide this information, and not all fields may be available at once.
Implementations