Module wrapper

Module wrapper 

Wrappers for different plugin types. Each wrapper has an entry point macro that you can pass the name of a type that implements Plugin to. The macro will handle the rest.

Modules

clap
standalone
A standalone plugin target that directly connects to the system’s audio and MIDI ports instead of relying on a plugin host. This is mostly useful for quickly testing GUI changes.
vst3

Functions

setup_logger
Set up the logger so that the nice_*!() logging and assertion macros log output to a centralized location and panics also get written there. By default this logs to STDERR. If a Windows debugger is attached, then messages will be sent there instead. This uses nice-log. See the readme there for more information.