Module clap

Module clap 

Modules

features
Features a plugin supports. This is essentially the same thing as tags, keyword, or categories. Hosts may use these to organize plugins.

Structs

PluginDescriptor
Re-export for the macro A static descriptor for a plugin. This is used in both the descriptor and on the plugin object itself.
PolyModulationConfig
Configuration for the plugin’s polyphonic modulation options, if it supports .
Wrapper
clap_host
clap_plugin
clap_plugin_descriptor
clap_plugin_entry
clap_plugin_factory

Constants

CLAP_PLUGIN_FACTORY_ID
CLAP_VERSION

Traits

ClapPlugin
Provides auxiliary metadata needed for a CLAP plugin.