Module vst3

Module vst3 

Re-exports

pub use vst3;

Modules

subcategories
Subcategories for VST3 plugins. This is essentially the same thing as tags, keyword, or categories. Hosts may use these to organize plugins.

Structs

PluginInfo
Re-export for the wrapper. The information queried about a plugin through the IPluginFactory* methods. Stored in a separate struct so it can be type erased and stored in an array.
Wrapper

Traits

Vst3Plugin
Provides auxiliary metadata needed for a VST3 plugin.