Vst3Plugin

Trait Vst3Plugin 

pub trait Vst3Plugin: Plugin {
    const VST3_CLASS_ID: [u8; 16];
    const VST3_SUBCATEGORIES: &'static [Vst3SubCategory];
    const PLATFORM_VST3_CLASS_ID: [u8; 16] = _;
}
Provides auxiliary metadata needed for a VST3 plugin.

Required Associated Constants

const VST3_CLASS_ID: [u8; 16]

The unique class ID that identifies this particular plugin. You can use the *b"fooofooofooofooo" syntax for this.

This will be shuffled into a different byte order on Windows for project-compatibility.

const VST3_SUBCATEGORIES: &'static [Vst3SubCategory]

One or more subcategories. The host may use these to categorize the plugin. Internally this slice will be converted to a string where each character is separated by a pipe character (|). This string has a limit of 127 characters, and anything longer than that will be truncated.

Provided Associated Constants

const PLATFORM_VST3_CLASS_ID: [u8; 16] = _

VST3_CLASS_ID in the correct order for the current platform so projects and presets can be shared between platforms. This should not be overridden.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors